﻿Imports SimpleProgress.Framework.Abstractions

Namespace Framework

    ''' <summary>
    ''' Server-side API for the SimpleProgress framework
    ''' </summary>
    Public Class ProgressManager
        Implements IProgressManager

        ''' <summary>
        ''' Header through which the ID that uniquely identifies the remote task is identified.
        ''' </summary>
        Public Const HeaderNameTaskId As String = "X-SimpleProgress-TaskId"

        Private ReadOnly _dataProvider As IProgressDataProvider

        ''' <summary>
        ''' Builds the root of the framework passing the component responsible for storing 
        ''' the status of each request. By default, status is stored in the ASP.NET cache.
        ''' </summary>
        Public Sub New()
            Me.New(New AspnetProgressProvider())
        End Sub
        Public Sub New(ByVal dataProvider As IProgressDataProvider)
            _dataProvider = dataProvider
        End Sub

        ''' <summary>
        ''' Used by controllers (or worker services) to set the percentage of work completed.
        ''' </summary>
        ''' <param name="taskId">ID of the current task being monitored</param>
        ''' <param name="percentage">Percentage of the work accomplished</param>
        Public Sub SetCompleted(ByVal taskId As String, ByVal percentage As Int32) Implements Abstractions.IProgressManager.SetCompleted
            If String.IsNullOrEmpty(taskId) Then
                Exit Sub
            End If
            percentage = If(percentage < 0, 0, percentage)
            percentage = If(percentage > 100, 100, percentage)

            Dim [step] = String.Format("{0} %", percentage)
            _dataProvider.Set(taskId, [step])
        End Sub

        ''' <summary>
        ''' Used by controllers (or worker services) to set a description of the current task. 
        ''' </summary>
        ''' <param name="taskId">ID of the current task being monitored</param>
        ''' <param name="step">Description of the current stage</param>
        Public Sub SetCompleted(ByVal taskId As String, ByVal [step] As String) Implements Abstractions.IProgressManager.SetCompleted
            If String.IsNullOrEmpty(taskId) Then
                Exit Sub
            End If

            _dataProvider.Set(taskId, [step])
        End Sub

        ''' <summary>
        ''' Returns the status of the current task.
        ''' </summary>
        ''' <param name="taskId">ID of the current task being monitored</param>
        ''' <returns>Current status of the task</returns>
        Public Function GetStatus(ByVal taskId As String) As String Implements Abstractions.IProgressManager.GetStatus
            Const invalidStatus As String = "..."
            If String.IsNullOrEmpty(taskId) Then
                Return invalidStatus
            End If

            Dim buffer = _dataProvider.Get(taskId)
            Return If(String.IsNullOrEmpty(buffer), invalidStatus, buffer)
        End Function

    End Class
End Namespace