﻿Namespace Framework
    ''' <summary>
    ''' Shields some common tasks for a controller that includes monitorable operations.
    ''' </summary>
    Public Class SimpleProgressController
        Inherits Controller
        Protected ReadOnly ProgressManager As ProgressManager

        ''' <summary>
        ''' Initializes a progress manager instance.
        ''' </summary>
        Public Sub New()
            ProgressManager = New ProgressManager()
        End Sub

        ''' <summary>
        ''' Retrieves the ID of the current task (via HTTP header)
        ''' </summary>
        ''' <returns>Task ID</returns>
        Public Function GetTaskId() As String
            ' Get the header with the task ID
            Dim id = Request.Headers(ProgressManager.HeaderNameTaskId)
            Return If(id, String.Empty)
        End Function

        ''' <summary>
        ''' Endpoint that retrieves the current status of an operation.
        ''' </summary>
        ''' <returns>Description</returns>
        Public Function Progress() As String
            Dim taskId = GetTaskId()
            Return ProgressManager.GetStatus(taskId)
        End Function
    End Class
End Namespace