///////////////////////////////////////////////////////////////////////
// Constants


var SimpleProgress = function () {
    var that = {};

    // Get the current task ID
    that._taskId = 0;

    // Get the timer ID used to push refreshes
    that._timerId = 0;

    // Get the URL to invoke to read status
    that._progressUrl = "";

    // Get the current interval for progress refresh
    that._interval = 500;

    // Get the user-defined callback that refreshes the UI 
    that._userDefinedProgressCallback = null;

    // Get the user-defined callback that finalizes the call 
    that._taskCompletedCallback = null;

    // Get a new task ID
    that.createTaskId = function () {
        var _minNumber = 100,
            _maxNumber = 1000000000;
        return _minNumber + Math.floor(Math.random() * _maxNumber);
    };

    // Set progress callback
    that.callback = function (userCallback, completedCallback) {
        that._userDefinedProgressCallback = userCallback;
        that._taskCompletedCallback = completedCallback;
        return this;
    };

    // Set frequency of refresh
    that.setInterval = function (interval) {
        that._interval = interval;
        return this;
    };


    // INTERNAL FUNCTION
    that._internalProgressCallback = function () {
        that._timerId = window.setTimeout(that._internalProgressCallback, that._interval);
        $.ajax({
            url: that._progressUrl,
            cache: false,
            headers: { 'X-SimpleProgress-TaskId': that._taskId },
            success: function (status) {
                if (that._userDefinedProgressCallback != null)
                    that._userDefinedProgressCallback(status);
            }
        });
    };

    // Invoke the URL and monitor its progress
    that.start = function (url, progressUrl) {
        that._taskId = that.createTaskId();
        that._progressUrl = progressUrl;

        // Place the Ajax call
        $.ajax({
            url: url,
            cache: false,
            headers: { 'X-SimpleProgress-TaskId': that._taskId },
            success: function (data) {
                if (that._taskCompletedCallback != null)
                    that._taskCompletedCallback(data);
                that.end();
            }
        });

        // Start the callback (if any)
        if (that._userDefinedProgressCallback == null)
            return this;
        that._timerId = window.setTimeout(that._internalProgressCallback, that._interval);
    };

    // Finalize the task
    that.end = function () {
        that._taskId = 0;
        window.clearTimeout(that._timerId);
    }

    return that;
};

